==> polars-core-0.14.4.crate: polars-core-0.14.4/src/prelude.rs <==
//! Everything you need to get started with Polars.
pub(crate) use crate::frame::groupby::aggregations::*;
pub use crate::{
    chunked_array::{
        arithmetic::Pow,
        builder::{
            BooleanChunkedBuilder, ChunkedBuilder, ListBooleanChunkedBuilder, ListBuilderTrait,
            ListPrimitiveChunkedBuilder, ListUtf8ChunkedBuilder, NewChunkedArray,
            PrimitiveChunkedBuilder, Utf8ChunkedBuilder,
        },
        comparison::NumComp,
        iterator::{IntoNoNullIterator, PolarsIterator},
        ops::{
            aggregate::*,
            chunkops::ChunkOps,
            take::AsTakeIndex,
            take_random::{IntoTakeRandom, NumTakeRandomChunked, NumTakeRandomCont},
            window::InitFold,
            *,
        },
        ChunkedArray,
    },
    datatypes,
    datatypes::*,
    error::{PolarsError, Result},
    frame::{hash_join::JoinType, DataFrame},
    series::{
        arithmetic::{LhsNumOps, NumOpsDispatch},
        IntoSeries, NamedFrom, Series, SeriesTrait,
    },
    testing::*,
    utils::IntoVec,
    vector_hasher::VecHash,
};
pub use arrow::datatypes::{ArrowPrimitiveType, Field as ArrowField, Schema as ArrowSchema};
pub(crate) use polars_arrow::array::*;
pub use polars_arrow::vec::AlignedVec;
pub use std::sync::Arc;

#[cfg(feature = "object")]
pub use crate::chunked_array::object::PolarsObject;
#[cfg(feature = "temporal")]
pub use crate::chunked_array::temporal::conversion::*;
#[cfg(feature = "checked_arithmetic")]
pub use crate::series::arithmetic::checked::NumOpsDispatchChecked;

==> polars-core-0.14.8.crate: polars-core-0.14.8/src/prelude.rs <==
//! Everything you need to get started with Polars.
pub(crate) use crate::frame::groupby::aggregations::*;
pub use crate::{
    chunked_array::{
        arithmetic::Pow,
        builder::{
            BooleanChunkedBuilder, ChunkedBuilder, ListBooleanChunkedBuilder, ListBuilderTrait,
            ListPrimitiveChunkedBuilder, ListUtf8ChunkedBuilder, NewChunkedArray,
            PrimitiveChunkedBuilder, Utf8ChunkedBuilder,
        },
        comparison::NumComp,
        iterator::{IntoNoNullIterator, PolarsIterator},
        ops::{
            aggregate::*,
            chunkops::ChunkOps,
            take::AsTakeIndex,
            take_random::{IntoTakeRandom, NumTakeRandomChunked, NumTakeRandomCont},
            window::InitFold,
            *,
        },
        ChunkedArray,
    },
    datatypes,
    datatypes::*,
    error::{PolarsError, Result},
    frame::{hash_join::JoinType, DataFrame},
    series::{
        arithmetic::{LhsNumOps, NumOpsDispatch},
        IntoSeries, NamedFrom, Series, SeriesTrait,
    },
    testing::*,
    utils::IntoVec,
    vector_hasher::VecHash,
};
pub use arrow::datatypes::{ArrowPrimitiveType, Field as ArrowField, Schema as ArrowSchema};
pub use polars_arrow::vec::AlignedVec;
pub(crate) use polars_arrow::{array::*, trusted_len::TrustedLen};
pub use std::sync::Arc;

#[cfg(feature = "object")]
pub use crate::chunked_array::object::PolarsObject;
#[cfg(feature = "temporal")]
pub use crate::chunked_array::temporal::conversion::*;
#[cfg(feature = "checked_arithmetic")]
pub use crate::series::arithmetic::checked::NumOpsDispatchChecked;
